.. _credits:

********
Credits
********

* `Requests module <https://requests.readthedocs.io/en/latest>`_
* `URLLib module <https://docs.python.org/3/library/urllib.html>`_
* `Re module <https://docs.python.org/3/library/re.html>`_
* `Time module <https://docs.python.org/3/library/time.html>`_
* `Random module <https://docs.python.org/3/library/random.html>`_

Credits to the providers used in the providers dictionary under the Providers class, as well as API providers such as AlphaVantage and CNBC.

Thank you for those of you who gave out suggestions for the initial release of V2! `Gr1pp717 <https://www.reddit.com/user/Gr1pp717/>`_ helped out with such research in `this post <https://www.reddit.com/r/Python/comments/18sxqsc/comment/kfln8r3/?utm_source=share&utm_medium=web2x&context=3>`_

Some credits for update V2.1.0: `striata <https://www.reddit.com/user/striata/>`_ for the suggestions on following PEP guidelines and code efficiency enhancements in `this post <https://www.reddit.com/r/Python/comments/18uuyjr/comment/kfnju1d/?utm_source=share&utm_medium=web2x&context=3>`_, thank you! Also, `PandaStacker <https://github.com/PandaStacker>`_, for taking the time to suggest new functions for Stockstir in `this pull request <https://github.com/PatzEdi/Stockstir/pull/3>`_. Thanks for the contributions!

For the random_user_agents parameter used in the GatherInfo class, I got the user agents list from a project called slowloris which can be found on GitHub. Big credits to that list of user agents and the developer of slowloris as I used the list of user agents that the developer of slowloris used in this project. 

Link to slowloris: `Slowloris <https://github.com/gkbrk/slowloris>`_